powered by
Each point is placed around its projection using the normal distribution (=0μ=0, =σ= lat_disp ).
lat_disp
clupoints_n(projs, lat_disp, line_len, clu_dir, clu_ctr)
Generated points (p np x n matrix).
Point projections on the cluster-supporting line (p np x n matrix).
Standard deviation for the normal distribution, i.e., cluster lateral dispersion.
Length of cluster-supporting line (ignored).
Direction of the cluster-supporting line.
Center position of the cluster-supporting line (ignored).
This function's main intended use is by the main clugen function, generating the final points when the point_dist_fn parameter is set to "n".
point_dist_fn
"n"
set.seed(123) ctr <- c(0, 0) dir <- c(1, 0) pdist <- c(-0.5, -0.2, 0.1, 0.3) proj <- points_on_line(ctr, dir, pdist) clupoints_n(proj, 0.01, NA, dir, NA)
Run the code above in your browser using DataLab